<?php

    /*
     * This example provides a basic demonstration of how Mail_IMAP can be used to
     * create an Inbox.
     *
     * See {@link imap_open} to view how the connection argument is passed.
     *
    */

    require_once('Mail/IMAP.php');

    // Set up class, initiate a mailbox connection
    $msg =& new Mail_IMAP();

    // Open up a mail connection
    // pop3://user:pass@mail.example.com:110/INBOX#notls
    // Use an existing imap resource stream, or provide a URI abstraction.
    //
    // If you are unsure of the URI syntax to use here, 
    // use the Mail_IMAP_connection_wizard to find the right URI.
    // Or see docs for Mail_IMAP::connect
    //
    // This argument must also be set in MAIL_IMAP.message.php.
    if (PEAR::isError($msg->connect('pop3://user:pass@mail.example.com:110/INBOX#notls'))) {
        echo "<span style='font-weight: bold;'>Error:</span> Unable to build a connection.";  
    }

    // Retrieve message count
    $msgcount = $msg->messageCount();

    echo "
        <html>
            <head>
                <title> Mail_IMAP Inbox </title>
                <style type='text/css' media='screen'>

                    table.msg
                    {
                        border: 1px solid black;
                        width: 100%;
                    }

                    td.msgattach, td.msgattach a
                    {
                        font-size: 8pt;
                        text-decoration: none;
                        padding: 5px;
                    }

                    td.msgitem
                    {
                        font-weight: bold;
                        padding: 5px;
                    }

                    td.msghead
                    {
                        border: 1px solid black;
                        font-weight: bold;
                        padding: 5px;
                        font-size: 14pt;
                    }

                    td.footer
                    {
                        font-size: 8pt;
                        text-align: right;
                        font-weight: bold;
                        padding: 5px;
                        border: 1px solid black;
                    }

                </style>
            </head>
            <body>
                <table class='msg'>
                    <tr>
                        <td class='msghead'>
                            subject
                        </td>
                        <td class='msghead'>
                            from
                        </td>
                        <td class='msghead'>
                            received
                        </td>
                    </tr>\n";

    /* 
     * Each message of a mailbox is numbered offset from 1
     * Create the $mid (message id) and recursively gather
     * message information.
     *
     * @source 88 1
    */

    for ($mid = 1; $mid <= $msgcount; $mid++)
    {
        // Get the default part id
        $pid = $msg->getDefaultPid($mid);

        // Parse header information
        $msg->getHeaders($mid, $pid);

        // Parse inline/attachment information specific to this part id
        //
        // See member variables begining with in or attach for
        // available information
        $msg->getParts($mid, $pid);

        echo "                        <tr>\n",
             "                            <td class='msgitem'><a href='Mail_IMAP.message.php?mid={$mid}&amp;pid={$pid}' target='_blank'>{$msg->header[$mid]['subject']}</a></td>\n",
             "                            <td class='msgitem'>\n",
             "                              ", (isset($msg->header[$mid]['from_personal'][0]) && !empty($msg->header[$mid]['from_personal'][0]))? '<span title="'.$msg->header[$mid]['from'][0].'">'.$msg->header[$mid]['from_personal'][0]."</span>" : $msg->header[$mid]['from'][0], "\n",
             "                            </td>\n",
             "                            <td class='msgitem'>".date('D, M d, Y h:i:s', $msg->header[$mid]['udate'])."</td>\n",
             "                        </tr>\n",
             "                        <tr>\n",
             "                            <td colspan='3' class='msgattach'>\n";

        // Show inline parts first
        if (isset($msg->inPid[$mid]) && count($msg->inPid[$mid]) > 0)
        {
            foreach ($msg->inPid[$mid] as $i => $inid)
            {
                echo "                              Inline part: <a href='Mail_IMAP.message.php?mid={$mid}&amp;pid={$msg->inPid[$mid][$i]}' target='_blank'>{$msg->inFtype[$mid][$i]} ".$msg->convertBytes($msg->inFsize[$mid][$i])."</a><br />\n";
            }
        }

        // Now the attachments
        if (isset($msg->attachPid[$mid]) && count($msg->attachPid[$mid]) > 0)
        {
            foreach ($msg->attachPid[$mid] as $i => $aid)
            {
                echo "                              Attachment: <a href='Mail_IMAP.message.php?mid={$mid}&amp;pid={$msg->attachPid[$mid][$i]}' target='_blank'>{$msg->attachFname[$mid][$i]} {$msg->attachFtype[$mid][$i]} ".$msg->convertBytes($msg->attachFsize[$mid][$i])."</a><br />\n";
            }
        }

        echo "                            </td>\n",
             "                        </tr>\n";

        // Clean up left over variables
        $msg->unsetParts($mid);
        $msg->unsetHeaders($mid);
    }

    echo "                        <tr>\n",
         "                          <td colspan='3' class='footer'>\n",
         "                              mailbox: email@mailhost.com\n",
         "                          </td>\n",
         "                      </tr>\n",
         "                  </table>\n",
         "          </body>\n",
         "      </html>";

    // Close the stream
    $msg->close();
?>